function [Calculated_age,Th_232_neon_prod,U_238_neon_prod,U_235_neon_prod] = alpha_fluence_ratio(Th_232_yields,U_238_yields,U_235_yields,~,~,~,Th_U_Ratio,Ne_He_Ratio)


%% User inputs

Th_U_Ratio;               % Th/U ratio (by weight)
Ne_He_Ratio;              % Ne/He ratio (atomic)

%% Defined and calculated values

Th_U_Atomic = Th_U_Ratio*(238.02891/232.03806);     % Th/U atomic ratio

Th_232_lambda = log(2)/1.405e10;                    % Half-life of thorium-232
U_238_lambda = log(2)/4.468e9;                      % Half-life of uranium-238
U_235_lambda = log(2)/7.04e8;                       % Half-life of uranium-235
U_isotope_ratio = 137.88;                            % This can be changed to reflect updated values

%% Create alpha production matrix

t = logspace(0,log10(6e9),3000);                           % log-spaced time vector back to six billion years

Th_232_decays = Th_U_Atomic*(1+1/U_isotope_ratio)*(exp(Th_232_lambda*t)-1);     % decays through time from thorium-232 (normalized to 238U = 1)
U_238_decays = 1*(exp(U_238_lambda*t)-1);                                       % decays through time from uranium-238 (238U = 1)
U_235_decays = (1/U_isotope_ratio)*(exp(U_235_lambda*t)-1);                     % decays through time from uranium-235 (normalized to 238U = 1)

% set(0,'defaultaxesposition',[0.1 0.1 0.8 0.8])
% figure(3)
% plot(t,Th_232_decays,t,U_238_decays,t,U_235_decays)
% title('Alpha production from each isotope if sample is a given age')
% legend('Thorium-232','Uranium-238','Uranium-235')

%% Compute neon production rates

Th_232_alpha_production_rates = Th_232_yields;            % Production rate of each alpha from thorium-232 decay in the material of interest
U_238_alpha_production_rates = U_238_yields;              % Production rate of each alpha from uranium-238 decay in the material of interest
U_235_alpha_production_rates = U_235_yields;              % Production rate of each alpha from uranium-235 decay in the material of interest

Th_232_neon = sum(Th_232_decays'*Th_232_alpha_production_rates,2);                  % Production of neon from thorium-232 alphas
U_238_neon = sum(U_238_decays'*U_238_alpha_production_rates,2);                     % Production of neon from uranium-238 alphas
U_235_neon = sum(U_235_decays'*U_235_alpha_production_rates,2);                     % Production of neon from uranium-235 alphas
Total_neon = Th_232_neon + U_238_neon + U_235_neon;                                 % Production of neon from all alphas

%% Compute neon/helium ratio

Th_232_alphas = Th_232_decays'*6;
U_238_alphas = U_238_decays'*8;
U_235_alphas = U_235_decays'*7;
Total_alphas = Th_232_alphas + U_238_alphas + U_235_alphas;

Th_232_Ratio = Th_232_neon./Th_232_alphas;
U_238_Ratio = U_238_neon./U_238_alphas;
U_235_Ratio = U_235_neon./U_235_alphas;
Ratio = Total_neon./Total_alphas;

% figure(4)
% plot(t,Th_232_Ratio,t,U_238_Ratio,t,U_235_Ratio,t,Ratio)
% title('Neon to helium-4 production ratio in sample of a given age')
% legend('Thorium-232','Uranium-238','Uranium-235','Total')

%% Find the age
[trash ind] = min(abs(Ne_He_Ratio-Ratio));
Calculated_ratio = Ratio(ind);
Calculated_age = t(ind);

if ind == length(Ratio) || ind == 1
    Th_232_neon_prod = ' ';
    U_238_neon_prod = ' ';
    U_235_neon_prod = ' ';
    Calculated_age = 'Error: ratio not possible';
else
    error_range = (t(ind+1)-t(ind-1));
    t_fine_scale = linspace(t(ind-1),t(ind+1),3000);

    while error_range > 100

        Th_232_decays = Th_U_Atomic*(1+1/U_isotope_ratio)*(exp(Th_232_lambda*t_fine_scale)-1);   % decays through time from thorium-232
        U_238_decays = 1*(exp(U_238_lambda*t_fine_scale)-1);      % decays through time from uranium-238
        U_235_decays = (1/U_isotope_ratio)*(exp(U_235_lambda*t_fine_scale)-1);      % decays through time from uranium-235

        Th_232_neon = sum(Th_232_decays'*Th_232_alpha_production_rates,2);  % Production of neon from thorium-232 alphas
        U_238_neon = sum(U_238_decays'*U_238_alpha_production_rates,2);     % Production of neon from uranium-238 alphas
        U_235_neon = sum(U_235_decays'*U_235_alpha_production_rates,2);     % Production of neon from uranium-235 alphas
        Total_neon = Th_232_neon + U_238_neon + U_235_neon;                 % Production of neon from all alphas

        [~,ind] = min(abs(Ne_He_Ratio-Ratio));
        Calculated_ratio = Ratio(ind);
        Calculated_age = t_fine_scale(ind);

        t_fine_scale = linspace(t_fine_scale(ind-1),t_fine_scale(ind+1),3000);
        error_range = (t_fine_scale(ind+1)-t_fine_scale(ind-1));

    end

    Th_232_neon_prod = 1000*22.414/6.022e23*Th_232_Ratio(1)*6;
    U_238_neon_prod = 1000*22.414/6.022e23*U_238_Ratio(1)*8;
    U_235_neon_prod = 1000*22.414/6.022e23*U_235_Ratio(1)*7;
    Calculated_age = t_fine_scale(ind);
end
